@@ -9,11 +9,11 @@ SeaBASS::File - Object-oriented interface for reading/writing SeaBASS files
 
 =head1 VERSION
 
-version 0.151940
+version 0.162580
 
 =cut
 
-our $VERSION = '0.151940'; # VERSION
+our $VERSION = '0.162580'; # VERSION
 
 =head1 SYNOPSIS
 
@@ -284,7 +284,7 @@ my @ABSOLUTELY_REQUIRED_HEADERS = qw(
 );
 
 # Valid headers used for STRICT_READ and STRICT_WRITE
-my @ALL_HEADERS = qw(
+our @ALL_HEADERS = qw(
 	begin_header
 	investigators
 	affiliations
@@ -313,6 +313,7 @@ my @ALL_HEADERS = qw(
 	wind_speed
 	missing
 	below_detection_limit
+	above_detection_limit
 	delimiter
 	fields
 	units
@@ -433,8 +434,8 @@ deleted.  They cannot be retrieved using C<headers> and will not be written.
 =item * missing_data_to_undef
 
 C<1> or C<0>, default C<1>.  If any values in the data block are equal to the
-/missing or /below_detection_limit headers, they are set to undef when they 
-are retrieved.
+/missing, /above_detection_limit, /below_detection_limit headers, they are set
+to undef when they are retrieved.
 
 =item * preserve_comments
 
@@ -1528,6 +1529,7 @@ sub write {
 
 		my $missing = ( exists( $self->{'missing'} ) ? $self->{'missing'} : $DEFAULT_MISSING );
 		my $bdl     = ( exists( $self->{'below_detection_limit'} ) ? $self->{'below_detection_limit'} : $DEFAULT_MISSING );
+		my $adl     = ( exists( $self->{'above_detection_limit'} ) ? $self->{'above_detection_limit'} : $DEFAULT_MISSING );
 
 		if ( $self->{'options'}{'preserve_header'} ) {
 			print join("\n", @{ $self->{'preserved_header'} }, '');
@@ -1546,10 +1548,12 @@ sub write {
 			
 			my @headers_to_print;
 			
+			@headers_to_print = @ALL_HEADERS;
+			if ($missing eq $adl || $self->{'options'}{'missing_data_to_undef'}){
+				@headers_to_print = grep(!/above_detection_limit/i, @headers_to_print);
+			}
 			if ($missing eq $bdl || $self->{'options'}{'missing_data_to_undef'}){
-				@headers_to_print = grep(!/below_detection_limit/i, @ALL_HEADERS);
-			} else {
-				@headers_to_print = @ALL_HEADERS;
+				@headers_to_print = grep(!/below_detection_limit/i, @headers_to_print);
 			}
 			
 			unless (grep($_ ne 'unitless', @{ $self->{'actual_units'} })){
@@ -1699,9 +1703,11 @@ sub make_data_hash {
 		if ( $self->{'options'}{'missing_data_to_undef'} ) {
 			if ( $self->{'missing_is_number'} && looks_like_number($v) && $v == $self->{'missing'} ) {
 				$ret{$k} = undef;
+			} elsif ( $self->{'adl_is_number'} && looks_like_number($v) && $v == $self->{'above_detection_limit'} ){
+				$ret{$k} = undef;
 			} elsif ( $self->{'bdl_is_number'} && looks_like_number($v) && $v == $self->{'below_detection_limit'} ){
 				$ret{$k} = undef;
-            } elsif ($v eq $self->{'missing'} || $v eq $self->{'below_detection_limit'}) {
+            } elsif ($v eq $self->{'missing'} || $v eq $self->{'below_detection_limit'} || $v eq $self->{'above_detection_limit'}) {
 				$ret{$k} = undef;
             } else {
 				$ret{$k} = $v;
@@ -2052,6 +2058,7 @@ sub read_headers {
 
 	$self->{'missing'}               = $missing;
 	$self->{'below_detection_limit'} = $headers{"${slash}below_detection_limit"} || $missing;
+	$self->{'above_detection_limit'} = $headers{"${slash}above_detection_limit"} || $missing;
 	$self->{'line_number'}           = $line_number;
 	$self->{'data_start_line'}       = $line_number;
 	$self->{'data_start_position'}   = $position;
@@ -2205,6 +2212,9 @@ sub validate_header {
 	} elsif ( $k =~ m"^/?missing$" ) {
 		$self->{'missing'} = ( length($v) ? $v : $DEFAULT_MISSING );
 		$self->{'missing_is_number'} = looks_like_number( $self->{'missing'} );
+	} elsif ( $k =~ m"^/?above_detection_limit" ) {
+		$self->{'above_detection_limit'} = ( length($v) ? $v : $self->{'missing'} );
+		$self->{'adl_is_number'} = looks_like_number( $self->{'above_detection_limit'} );
 	} elsif ( $k =~ m"^/?below_detection_limit" ) {
 		$self->{'below_detection_limit'} = ( length($v) ? $v : $self->{'missing'} );
 		$self->{'bdl_is_number'} = looks_like_number( $self->{'below_detection_limit'} );
